<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema"
                exclude-result-prefixes="xs" version="2.0" xmlns="http://www.w3.org/1999/xhtml">
    <xsl:output method="html" omit-xml-declaration="yes" indent="yes"/>
    <xsl:template name="formatDate">
        <xsl:param name="yyyy-mm-dd"/>
        <xsl:choose>
            <xsl:when test="string-length($yyyy-mm-dd)>0">
                <xsl:variable name="yyyy" select="substring-before($yyyy-mm-dd, '-')"/>
                <xsl:variable name="mm-dd" select="substring-after($yyyy-mm-dd, '-')"/>
                <xsl:variable name="mm" select="substring-before($mm-dd, '-')"/>
                <xsl:variable name="dd" select="substring-after($mm-dd, '-')"/>
                <xsl:value-of select="concat($dd, '.',$mm,'.',$yyyy)"/>
            </xsl:when>
        </xsl:choose>
    </xsl:template>

    <xsl:template name="formatAmount">
        <xsl:param name="amount"/>
        <xsl:choose>
            <xsl:when test="string-length($amount)>0">
                <xsl:value-of select="format-number($amount, '###,##0.00')"/>
            </xsl:when>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="/">
        <html>
            <head>
                <meta charset="UTF-8"/>
                <style type="text/css">
                    body {
                        margin: 0;
                        font-family: Arial, sans-serif;
                        font-size: 14px;
                    }

                    table {
                        border-collapse: collapse;
                        font-size: 11pt;
                    }

                    table td {
                        border: 1px solid black;
                        border-color: black;
                    }

                    table th {
                        border: 1px solid black;
                        border-color: black;
                        text-align: center;
                    }

                    td {
                        mso-number-format: \@ !important;
                        vertical-align: middle;
                        mso-char-indent: 0;
                    }

                    .bolded {
                        font-weight: bold;
                    }

                    .cent {
                        text-align: center;
                    }

                    .ttop {
                        vertical-align: top;
                    }

                    .vbot {
                        vertical-align: bottom !important;
                    }

                    .num {
                        text-align: right !important;
                    }

                    .sum {
                        text-align: right !important;
                    }

                    .txt {
                        text-align: left !important;
                    }

                    .dat {
                        text-align: center !important;
                    }

                    .notice td, .notice th {
                        border: 1px solid black;
                        border-color: black;
                        text-align: center;
                    }

                    .notice th {
                        background-color: #eee;
                        text-align: center;
                    }

                    .rectangle {
                        border: #000 1pt solid;
                    }

                    .linetop {
                        border-top: #000 1pt solid;
                    }

                    .linebottom {
                        border-bottom: #000 1pt solid;
                    }

                    .lineleft {
                        border-left: #000 1pt solid;
                        padding-left: 1mm;
                    }

                    .accent {
                        font-weight: bold;
                        font-size: 11pt;
                        line-height: 1;
                    }

                    .data {
                        font-size: 11pt;
                        vertical-align: top;
                    }

                    .field {
                        font-size: 9pt;
                        line-height: 1.4;
                        height: 5mm;
                        vertical-align: top;
                    }

                    .addit {
                        padding-top: 10px;
                        color: #666;
                    }

                    #itbl1 {
                        width: 190mm;
                        margin: 10mm;
                    }

                    #itbl2 {
                        width: 170mm;
                        margin: 10mm;
                        line-height: 18px;
                    }

                    #itbl3 {
                        margin: 10mm;
                        line-height: 18px;
                    }

                    .move {
                        margin: 10mm;
                        line-height: 18px;
                    }
                </style>
                <style type="text/css" media="print">
                    #itbl1, #itbl2 {
                        margin: 0 auto 0 auto;
                    }
                </style>
            </head>
            <body>
                <xsl:for-each select="//CCX26">
                    <div class="move">
                        <center>
                            <span class="accent">Отчет о начисленных и выплаченных процентах по депозитным договорам
                            </span>
                            <br/>
                            <span class="accent">
                                <xsl:choose>
                                    <xsl:when test="@DATE_TO = @DATE_FROM">
                                        за
                                        <xsl:call-template name="formatDate">
                                            <xsl:with-param name="yyyy-mm-dd" select="@DATE_FROM"/>
                                        </xsl:call-template>
                                    </xsl:when>
                                    <xsl:when test="@DATE_TO">
                                        за период с
                                        <xsl:call-template name="formatDate">
                                            <xsl:with-param name="yyyy-mm-dd" select="@DATE_FROM"/>
                                        </xsl:call-template>
                                        по
                                        <xsl:call-template name="formatDate">
                                            <xsl:with-param name="yyyy-mm-dd" select="@DATE_TO"/>
                                        </xsl:call-template>
                                    </xsl:when>
                                </xsl:choose>
                            </span>
                            <br/>
                            <br/>
                        </center>
                        <span class="accent">Наименование Участника клиринга:&#160;</span>
                        <xsl:value-of select="@FIRMPURPOSE_PAYMENT"/>
                        <br/>
                        <span class="accent">Идентификатор Участника клиринга:&#160;</span>
                        <xsl:value-of select="@REGCODE"/>
                        <br/>
                        <span class="accent">Дата формирования отчета:&#160;</span>
                        <xsl:call-template name="formatDate">
                            <xsl:with-param name="yyyy-mm-dd" select="@DATE"/>
                        </xsl:call-template>
                        <br/>

                        <xsl:for-each select="STATEMENT">
                            <br/>
                            <span class="accent">Лицевой счет:&#160;</span>
                            <xsl:value-of select="@ACCOUNT"/>
                            <br/>
                            <span class="accent">Наименование лицевого счета:&#160;</span>
                            <xsl:value-of select="@PURPOSE_PAYMENT_ACC"/>
                            <br/>
                            <span class="accent">Валюта счета:&#160;</span>
                            <xsl:value-of select="@CURRENCYNAME"/>
                            <br/>
                            <br/>

                            <xsl:choose>
                                <xsl:when test="@CURRENCY='RUB'">
                                    <table cellpadding="4">
                                        <tr>
                                            <th style="text-align: left; width: 50ex;">
                                                Входящий остаток по начисленным процентам по депозитным договорам на
                                                <xsl:call-template name="formatDate">
                                                    <xsl:with-param name="yyyy-mm-dd" select="@DATE_OPENING_BALANCE"/>
                                                </xsl:call-template>
                                            </th>
                                            <td class="sum" style="width: 15ex;">
                                                <xsl:call-template name="formatAmount">
                                                    <xsl:with-param name="amount" select="@OPENING_BALANCE"/>
                                                </xsl:call-template>
                                            </td>
                                        </tr>
                                    </table>
                                    <br/>
                                    <table cellpadding="4" width="100%">
                                        <thead>
                                            <tr>
                                                <th style="width: 8ex;">№</th>
                                                <th style="width: 15ex;">Дата операции</th>
                                                <th style="width: 20ex;">Дебет</th>
                                                <th style="width: 20ex;">Кредит</th>
                                                <th>Наименование операции</th>
                                            </tr>
                                        </thead>

                                        <xsl:for-each select="ENTRY">
                                            <tr>
                                                <td class="num">
                                                    <xsl:value-of select="@NUMBER"/>
                                                </td>
                                                <td class="dat">
                                                    <xsl:call-template name="formatDate">
                                                        <xsl:with-param name="yyyy-mm-dd" select="@OPERDATE"/>
                                                    </xsl:call-template>
                                                </td>
                                                <td class="sum">
                                                    <xsl:call-template name="formatAmount">
                                                        <xsl:with-param name="amount" select="@DEBIT"/>
                                                    </xsl:call-template>

                                                </td>
                                                <td class="sum">
                                                    <xsl:call-template name="formatAmount">
                                                        <xsl:with-param name="amount" select="@CREDIT"/>
                                                    </xsl:call-template>

                                                </td>
                                                <td>
                                                    <xsl:value-of select="@PURPOSE_PAYMENT"/>
                                                </td>
                                            </tr>
                                        </xsl:for-each>
                                        <tr>
                                            <th colspan="2" style="text-align: right;">
                                                Всего оборотов
                                            </th>
                                            <td class="sum">
                                                <xsl:call-template name="formatAmount">
                                                    <xsl:with-param name="amount" select="@DEBIT_SUM"/>
                                                </xsl:call-template>

                                            </td>
                                            <td class="sum">
                                                <xsl:call-template name="formatAmount">
                                                    <xsl:with-param name="amount" select="@CREDIT_SUM"/>
                                                </xsl:call-template>

                                            </td>
                                        </tr>

                                    </table>
                                    <br/>
                                    <table cellpadding="4">
                                        <tr>
                                            <th style="text-align: left; width: 50ex;">
                                                Исходящий остаток по начисленным процентам по депозитным договорам на
                                                <xsl:call-template name="formatDate">
                                                    <xsl:with-param name="yyyy-mm-dd" select="@DATE_CLOSING_BALANCE"/>
                                                </xsl:call-template>
                                            </th>
                                            <td class="sum" style="width: 15ex;">
                                                <xsl:call-template name="formatAmount">
                                                    <xsl:with-param name="amount" select="@CLOSING_BALANCE"/>
                                                </xsl:call-template>

                                            </td>
                                        </tr>
                                    </table>
                                </xsl:when>
                                <xsl:otherwise>
                                    <table cellpadding="4">
                                        <tr>
                                            <th rowspan="2" style="text-align: left; width: 50ex;">
                                                Входящий остаток по начисленным процентам по депозитным договорам на
                                                <xsl:call-template name="formatDate">
                                                    <xsl:with-param name="yyyy-mm-dd" select="@DATE_OPENING_BALANCE"/>
                                                </xsl:call-template>
                                            </th>
                                            <th style="width: 25ex;">
                                                в иностранной валюте
                                            </th>
                                            <th style="width: 25ex;">
                                                в нац. эквиваленте
                                            </th>
                                        </tr>
                                        <tr>
                                            <td class="sum">
                                                <xsl:call-template name="formatAmount">
                                                    <xsl:with-param name="amount" select="@OPENING_BALANCE"/>
                                                </xsl:call-template>

                                            </td>
                                            <td class="sum">
                                                <xsl:call-template name="formatAmount">
                                                    <xsl:with-param name="amount" select="@OPENING_BALANCE_RUB"/>
                                                </xsl:call-template>

                                            </td>
                                        </tr>
                                    </table>
                                    <br/>
                                    <table cellpadding="4" width="100%">
                                        <thead>
                                            <tr>
                                                <th rowspan="2" style="width: 8ex;">№</th>
                                                <th rowspan="2" style="width: 15ex;">Дата операции</th>
                                                <th style="width: 12ex;">Дебет</th>
                                                <th style="width: 12ex;">Кредит</th>
                                                <th style="width: 12ex;">Дебет</th>
                                                <th style="width: 12ex;">Кредит</th>
                                                <th rowspan="2">Наименование операции</th>
                                            </tr>
                                            <tr>
                                                <th colspan="2">в иностранной валюте</th>
                                                <th colspan="2">в нац. эквиваленте</th>
                                            </tr>
                                        </thead>

                                        <xsl:for-each select="ENTRY">
                                            <tr>
                                                <td class="num">
                                                    <xsl:value-of select="@NUMBER"/>
                                                </td>
                                                <td class="dat">
                                                    <xsl:call-template name="formatDate">
                                                        <xsl:with-param name="yyyy-mm-dd" select="@OPERDATE"/>
                                                    </xsl:call-template>
                                                </td>
                                                <td class="sum">
                                                    <xsl:call-template name="formatAmount">
                                                        <xsl:with-param name="amount" select="@DEBIT"/>
                                                    </xsl:call-template>

                                                </td>
                                                <td class="sum">
                                                    <xsl:call-template name="formatAmount">
                                                        <xsl:with-param name="amount" select="@CREDIT"/>
                                                    </xsl:call-template>

                                                </td>
                                                <td class="sum">
                                                    <xsl:call-template name="formatAmount">
                                                        <xsl:with-param name="amount" select="@DEBIT_RUB"/>
                                                    </xsl:call-template>

                                                </td>
                                                <td class="sum">
                                                    <xsl:call-template name="formatAmount">
                                                        <xsl:with-param name="amount" select="@CREDIT_RUB"/>
                                                    </xsl:call-template>

                                                </td>
                                                <td>
                                                    <xsl:value-of select="@PURPOSE_PAYMENT"/>
                                                </td>
                                            </tr>
                                        </xsl:for-each>
                                        <tr>
                                            <th colspan="2" style="text-align: right;">
                                                Всего оборотов
                                            </th>
                                            <td class="sum">
                                                <xsl:call-template name="formatAmount">
                                                    <xsl:with-param name="amount" select="@DEBIT_SUM"/>
                                                </xsl:call-template>

                                            </td>
                                            <td class="sum">
                                                <xsl:call-template name="formatAmount">
                                                    <xsl:with-param name="amount" select="@CREDIT_SUM"/>
                                                </xsl:call-template>

                                            </td>
                                            <td class="sum">
                                                <xsl:call-template name="formatAmount">
                                                    <xsl:with-param name="amount" select="@DEBIT_SUM_RUB"/>
                                                </xsl:call-template>

                                            </td>
                                            <td class="sum">
                                                <xsl:call-template name="formatAmount">
                                                    <xsl:with-param name="amount" select="@CREDIT_SUM_RUB"/>
                                                </xsl:call-template>

                                            </td>
                                        </tr>

                                    </table>
                                    <br/>
                                    <table cellpadding="4">
                                        <tr>
                                            <th rowspan="2" style="text-align: left; width: 50ex;">
                                                Исходящий остаток по начисленным процентам по депозитным договорам на
                                                <xsl:call-template name="formatDate">
                                                    <xsl:with-param name="yyyy-mm-dd" select="@DATE_CLOSING_BALANCE"/>
                                                </xsl:call-template>
                                            </th>
                                            <th style="width: 25ex;">
                                                в иностранной валюте
                                            </th>
                                            <th style="width: 25ex;">
                                                в нац. эквиваленте
                                            </th>
                                        </tr>
                                        <tr>
                                            <td class="sum">
                                                <xsl:call-template name="formatAmount">
                                                    <xsl:with-param name="amount" select="@CLOSING_BALANCE"/>
                                                </xsl:call-template>

                                            </td>
                                            <td class="sum">
                                                <xsl:call-template name="formatAmount">
                                                    <xsl:with-param name="amount" select="@CLOSING_BALANCE_RUB"/>
                                                </xsl:call-template>

                                            </td>
                                        </tr>
                                    </table>
                                </xsl:otherwise>
                            </xsl:choose>
                            <br/>
                        </xsl:for-each>
                    </div>
                </xsl:for-each>
            </body>
        </html>
    </xsl:template>
</xsl:stylesheet>
