<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema"
                exclude-result-prefixes="xs" version="2.0" xmlns="http://www.w3.org/1999/xhtml">
    <xsl:output method="html" omit-xml-declaration="yes" indent="yes"/>
    <xsl:template name="formatDate">
        <xsl:param name="yyyy-mm-dd"/>
        <xsl:choose>
            <xsl:when test="string-length($yyyy-mm-dd)>0">
                <xsl:variable name="yyyy" select="substring-before($yyyy-mm-dd, '-')"/>
                <xsl:variable name="mm-dd" select="substring-after($yyyy-mm-dd, '-')"/>
                <xsl:variable name="mm" select="substring-before($mm-dd, '-')"/>
                <xsl:variable name="dd" select="substring-after($mm-dd, '-')"/>
                <xsl:value-of select="concat($dd, '.',$mm,'.',$yyyy)"/>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    <xsl:template match="/">
        <html>
            <head>
                <meta charset="UTF-8"/>
                <style type="text/css">
                    body {
                        margin: 0;
                        font-family: Arial, sans-serif;
                        font-size: 14px;
                    }

                    table {
                        border-collapse: collapse;
                    }

                    td {
                        vertical-align: middle;
                        mso-char-indent: 0;
                    }

                    .dat {
                        text-align: center;
                    }

                    .num {
                        text-align: right !important;
                        mso-number-format: "0";
                    }

                    .sum {
                        text-align: right !important;
                        mso-number-format: "#\,##0.00##" !important;
                    }

                    .txt {
                        text-align: left !important;
                        mso-number-format: \@ !important;
                    }

                    .notice td, .notice th {
                        border: 1px solid black;
                        border-color: black;
                        text-align: center;
                        font-size: 8pt;
                    }

                    .notice th {
                        background-color: #eee;
                        text-align: center;
                    }

                    .rectangle {
                        border: #000 1pt solid;
                    }

                    .accent {
                        font-weight: bold;
                        font-size: 11pt;
                        line-height: 1;
                    }

                    .data {
                        font-size: 11pt;
                        vertical-align: top;
                    }

                    .field {
                        font-size: 9pt;
                        line-height: 1.4;
                        height: 5mm;
                        vertical-align: top;
                    }

                    #itbl1 {
                        width: 190mm;
                        margin: 10mm;
                    }

                    #itbl2 {
                        width: 170mm;
                        margin: 10mm;
                        line-height: 18px;
                    }

                    #itbl3 {
                        margin: 10mm;
                        line-height: 18px;
                    }

                    .move {
                        margin: 10mm;
                        line-height: 18px;
                    }
                </style>
                <style type="text/css" media="print">
                    #itbl1, #itbl2 {
                        margin: 0 auto 0 auto;
                    }
                </style>
            </head>
            <body>
                <xsl:for-each select="//CCX51">
                    <div class="move">
                        <center>
                            <span class="accent">Income paid to the Non-resident Clearing Member</span>
                            <br/>
                            <br/>
                            <span>Date:</span>&#160;
                            <xsl:call-template name="formatDate">
                                <xsl:with-param name="yyyy-mm-dd" select="@ReportDate"/>
                            </xsl:call-template>
                            <br/>
                            <br/>
                        </center>
                        <span class="accent">Name of the Clearing member:</span>&#160;
                        <xsl:value-of select="@FirmName"/>
                        <br/>
                        <span class="accent">Clearing Member's Identifier:</span>&#160;
                        <xsl:value-of select="@FirmID"/>
                        <br/>
                        <br/>
                        <br/>

                        <table class="notice" width="100%" cellpadding="4">
                            <thead>
                                <tr>
                                    <th>ID</th>
                                    <th>Trade type</th>
                                    <th>Market where tax is margined or withheld</th>
                                    <th>Settlement account</th>
                                    <th>Settlement account for tax</th>
                                    <th>Name of Income Recipient</th>
                                    <th>Code of Income Recipient</th>
                                    <th>Type of  Income Recipient</th>
                                    <th>Category of  Income Recipient</th>
                                    <th>Country</th>
                                    <th>Right</th>
                                    <th>Trade number</th>
                                    <th>Trade date</th>
                                    <th>Trade type</th>
                                    <th>Income number</th>
                                    <th>Code of type of security</th>
                                    <th>Name of type of security</th>
                                    <th>Security trading code</th>
                                    <th>Issue name</th>
                                    <th>Issuer</th>
                                    <th>Contract code</th>
                                    <th>Contract name</th>
                                    <th>Position</th>
                                    <th>Type</th>
                                    <th>Income payment date</th>
                                    <th>Code of type of income</th>
                                    <th>Name of type of income</th>
                                    <th>Currency</th>
                                    <th>Income sum before tax</th>
                                    <th>Rate</th>
                                    <th>Date of tax margining / withholding by tax agent</th>
                                    <th>Sum of tax, withheld from the source of payment of income between settlement dates of the 1st and 2nd parts of REPO</th>
                                    <th>Sum of tax withheld in the currency of income payment</th>
                                    <th>Interim sum of accrued tax in the currency of income payment</th>
                                    <th>Date of tax transfer to the budget</th>
                                    <th>Tax amount in rubles</th>
                                    <th>BCC</th>
                                </tr>
                            </thead>

                            <xsl:for-each select="RECORDS">
                                <tr>
                                    <td class="num">
                                        <xsl:value-of select="@Record_ID"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@TradeType"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:choose>
                                            <xsl:when test="@TCS = 'EQ'">
                                                Securities market and money market and deposit market
                                            </xsl:when>
                                            <xsl:when test="@TCS = 'CU'">
                                                FX market and precious metals market
                                            </xsl:when>
                                            <xsl:when test="@TCS = 'FU'">
                                                Derivatives market
                                            </xsl:when> 
                                            <xsl:otherwise>
                                                <xsl:value-of select="@TCS"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@ID"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@ID_Z"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@IncomeRecipient"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@ClientCode"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@IRCategoryCode"/>&#160;<xsl:value-of select="@IRCategory"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@TaxCategory"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@IR_CountryCode"/>&#160;<xsl:value-of select="@IR_Country"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@IncomeRight"/>
                                    </td>
                                    <td class="num">
                                        <xsl:value-of select="@TradeNo"/>
                                    </td>
                                    <td class="dat">
                                        <xsl:call-template name="formatDate">
                                            <xsl:with-param name="yyyy-mm-dd" select="@TradeDate"/>
                                        </xsl:call-template>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@TradeCode"/>
                                    </td>
                                    <td class="num">
                                        <xsl:value-of select="@IncomeNo"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@Secur_CBR"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@Secur_CBR_Name"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@SecID"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@SecTypeName"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@IssuerName"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@ContractCode"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@ContractName"/>
                                    </td>
                                    <td class="num">
                                        <xsl:value-of select="@Position"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:choose>
                                            <xsl:when test="@Type = '1'">Tax</xsl:when>
                                            <xsl:when test="@Type = '2'">Report</xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="@Type"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </td>
                                    <td class="dat">
                                        <xsl:call-template name="formatDate">
                                            <xsl:with-param name="yyyy-mm-dd" select="@IncomePaymentDate"/>
                                        </xsl:call-template>
                                    </td>
                                    <td class="num">
                                        <xsl:value-of select="@IncomeID"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@IncomeCode"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@IncomeCurrency"/>
                                    </td>
                                    <td class="sum">
                                        <xsl:value-of select="@IncomeValue"/>
                                    </td>
                                    <td class="sum">
                                        <xsl:value-of select="@TaxRate"/>
                                    </td>
                                    <td class="dat">
                                        <xsl:call-template name="formatDate">
                                            <xsl:with-param name="yyyy-mm-dd" select="@TaxWithholdDate"/>
                                        </xsl:call-template>
                                    </td>
                                    <td class="sum">
                                        <xsl:value-of select="@DeductTaxValue"/>
                                    </td>
                                    <td class="sum">
                                        <xsl:value-of select="@TaxValue"/>
                                    </td>
                                    <td class="sum">
                                        <xsl:value-of select="@MarginTaxValue"/>
                                    </td>
                                    <td class="dat">
                                        <xsl:call-template name="formatDate">
                                            <xsl:with-param name="yyyy-mm-dd" select="@TaxPaymentDate"/>
                                        </xsl:call-template>
                                    </td>
                                    <td class="sum">
                                        <xsl:value-of select="@TaxValueRub"/>
                                    </td>
                                    <td class="txt">
                                        <xsl:value-of select="@BCC"/>
                                    </td>
                                </tr>

                            </xsl:for-each>

                        </table>

                    </div>
                </xsl:for-each>

            </body>
        </html>
    </xsl:template>
</xsl:stylesheet>
