<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema"
                exclude-result-prefixes="xs" version="2.0" xmlns="http://www.w3.org/1999/xhtml">
    <xsl:output method="html" omit-xml-declaration="yes" indent="yes"/>
    <xsl:template name="formatDate">
        <xsl:param name="yyyy-mm-dd"/>
        <xsl:choose>
            <xsl:when test="string-length($yyyy-mm-dd)>0">
                <xsl:variable name="yyyy" select="substring-before($yyyy-mm-dd, '-')"/>
                <xsl:variable name="mm-dd" select="substring-after($yyyy-mm-dd, '-')"/>
                <xsl:variable name="mm" select="substring-before($mm-dd, '-')"/>
                <xsl:variable name="dd" select="substring-after($mm-dd, '-')"/>
                <xsl:value-of select="concat($dd, '.',$mm,'.',$yyyy)"/>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    <xsl:template match="/">
        <html>
            <head>
                <meta charset="UTF-8"/>
                <style type="text/css">
                    body {
                        margin: 0;
                        font-family: Arial, sans-serif;
                        font-size: 14px;
                    }

                    table {
                        border-collapse: collapse;
                    }

                    td {
                        mso-number-format: \@ !important;
                        vertical-align: middle;
                        mso-char-indent: 0;
                    }

                    .bolded {
                        font-weight: bold;
                    }

                    .cent {
                        text-align: center;
                    }

                    .ttop {
                        vertical-align: top;
                    }

                    .vbot {
                        vertical-align: bottom !important;
                    }

                    .num {
                        text-align: right !important;
                    }

                    .sum {
                        text-align: right !important;
                    }

                    .txt {
                        text-align: left !important;
                    }

                    .notice td, .notice th {
                        border: 1px solid black;
                        border-color: black;
                        text-align: center;
                    }

                    .notice th {
                        background-color: #eee;
                        text-align: center;
                    }

                    .rectangle {
                        border: #000 1pt solid;
                    }

                    .linetop {
                        border-top: #000 1pt solid;
                    }

                    .linebottom {
                        border-bottom: #000 1pt solid;
                    }

                    .lineleft {
                        border-left: #000 1pt solid;
                        padding-left: 1mm;
                    }

                    .accent {
                        font-weight: bold;
                        font-size: 11pt;
                        line-height: 1;
                    }

                    .data {
                        font-size: 11pt;
                        vertical-align: top;
                    }

                    .field {
                        font-size: 9pt;
                        line-height: 1.4;
                        height: 5mm;
                        vertical-align: top;
                    }

                    .addit {
                        padding-top: 10px;
                        color: #666;
                    }

                    #itbl1 {
                        width: 190mm;
                        margin: 10mm;
                    }

                    #itbl2 {
                        width: 170mm;
                        margin: 10mm;
                        line-height: 18px;
                    }

                    #itbl3 {
                        margin: 10mm;
                        line-height: 18px;
                    }

                    .move {
                        margin: 10mm;
                        line-height: 18px;
                    }
                </style>
                <style type="text/css" media="print">
                    #itbl1, #itbl2 {
                        margin: 0 auto 0 auto;
                    }
                </style>
            </head>
            <body>
                <xsl:for-each select="//CCX94">
                    <div class="move">
                        <center>
                            <span class="accent">УВЕДОМЛЕНИЕ О МИНИМАЛЬНОМ РАЗМЕРЕ ОБЕСПЕЧЕНИЯ ПОД СТРЕСС</span>
                            <br/>
                            <br/>
                        </center>
                        <span class="accent">Дата формирования отчета: </span>
                        <xsl:call-template name="formatDate">
                            <xsl:with-param name="yyyy-mm-dd" select="@ReportDate"/>
                        </xsl:call-template>
                        <br/>
                        <span class="accent">Наименование Участника клиринга: </span>
                        <xsl:value-of select="@FirmName"/>
                        <br/>
                        <span class="accent">Идентификатор Участника клиринга: </span>
                        <xsl:value-of select="@FirmId"/>
                        <br/>
                        <span class="accent">Расчетный код для учета Обеспечения под стресс: </span>
                        <xsl:value-of select="@ExtSettleCode"/>
                        <br/>
                        <span class="accent">Дата начала действия минимального размера Обеспечения под стресс: </span>
                        <xsl:call-template name="formatDate">
                            <xsl:with-param name="yyyy-mm-dd" select="@BEGIN_DATE"/>
                        </xsl:call-template>
                        <br/>
                        <br/>

                        <table class="notice" width="100%" cellpadding="4">
                            <col width="40%"/>
                            <col width="60%"/>
                            <thead>
                                <tr>
                                    <th>Рынок</th>
                                    <th>Минимальный размер Обеспечения под стресс, руб.</th>
                                </tr>
                            </thead>

                            <xsl:for-each select="RECORDS">
                                <tr>
                                    <td class="txt">
                                        <xsl:choose>
                                            <xsl:when test="@TCS = 'EQ'">
                                                Фондовый рынок и рынок депозитов
                                            </xsl:when>
                                            <xsl:when test="@TCS = 'CU'">
                                                Валютный рынок и рынок драгоценных металлов
                                            </xsl:when>
                                            <xsl:when test="@TCS = 'FU'">
                                                Срочный рынок
                                            </xsl:when>
                                            <xsl:when test="@TCS = 'OT'">
                                                Рынок СПФИ
                                            </xsl:when>
                                            <xsl:when test="@TCS = 'CO'">
                                                Товарный рынок
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="@TCS"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </td>
                                    <td class="sum">
                                        <xsl:for-each select="@SUM">
                                            <span>
                                                <xsl:value-of select="format-number(number(string(.)), '###,##0.00')"/>
                                            </span>
                                        </xsl:for-each>
                                    </td>
                                </tr>

                            </xsl:for-each>

                        </table>

                    </div>
                </xsl:for-each>

            </body>
        </html>
    </xsl:template>
</xsl:stylesheet>
