<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema"
                exclude-result-prefixes="xs" version="2.0" xmlns="http://www.w3.org/1999/xhtml">
    <xsl:output method="html" omit-xml-declaration="yes" indent="yes"/>
    <xsl:template match="/">
        <html>
            <head>
                <meta charset="UTF-8"/>
                <style type="text/css">
                    body {
                        margin: 0;
                        font-family: Arial, sans-serif;
                        font-size: 14px;
                    }

                    table {
                        border-collapse: collapse;
                    }

                    td {
                        mso-number-format: \@ !important;
                        vertical-align: middle;
                        mso-char-indent: 0;
                    }

                    
                    .accent {
                        font-weight: bold;
                        font-size: 11pt;
                        line-height: 1;
                    }
                    
                    .move {
                        margin: 10mm;
                        line-height: 18px;
                    }
                </style>

            </head>
            <body>
                <xsl:for-each select="//CCX98">
                    <div class="move">
                        <center>
                            <span class="accent">REPORT ON SETTLEMENT ACCOUNTS AND DETAILS OF THE CLEARING MEMBER</span>
                            <br/>
                            <br/>
                        </center>

                        <table width="50%" align="center" rules="groups">
                            <tr>
                                <td>
                                    <span class="accent">Registration code of the Clearing Member: </span>
                                    <xsl:value-of select="@REGCODE"/>
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    <span class="accent">Main Settlement Account of the Clearing Member: </span>
                                    <xsl:value-of select="@UVR_CODE"/>
                                </td>
                            </tr>
                        </table>
                        <br/>
                        <center>
                            <span class="accent">List of Settlement Accounts of the Clearing Member.</span>
                        </center>

                        <xsl:for-each select="//RC">

                            <table width="50%" align="center" cellpadding="4">
                                <COL width="30%" align="left"/>
                                <COL width="70%" align="left"/>
                                <thead>
                                    <tr bgcolor="#CCCCCC">
                                        <th align="left">
                                            <span style="font-weight:bold">
                                                <xsl:text>Settlement Account</xsl:text>
                                            </span>
                                        </th>
                                        <td>
                                            <xsl:for-each select="@ID">
                                                <span align="left" style="font-weight:bold">
                                                    <xsl:value-of select="string(.)"/>
                                                </span>
                                            </xsl:for-each>
                                        </td>
                                    </tr>

                                    <tr bgcolor="#CCCCCC">
                                        <th align="left">
                                            <span style="font-weight:bold">
                                                <xsl:text>Settlement Account type</xsl:text>
                                            </span>
                                        </th>
                                        <td>
                                            <span align="left" style="font-weight:bold">
                                                <xsl:choose>
                                                    <xsl:when test="@TYPE='S'">
                                                        <xsl:text>Own funds</xsl:text>
                                                    </xsl:when>
                                                    <xsl:when test="@TYPE='L'">
                                                        <xsl:text>Client&#39;s funds</xsl:text>
                                                    </xsl:when>
                                                    <xsl:when test="@TYPE='D'">
                                                        <xsl:text>Funds transferred to trust management</xsl:text>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:value-of select="@TYPE"/>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </span>
                                        </td>
                                    </tr>


                                    <tr bgcolor="#CCCCCC">
                                        <th align="left">
                                            <span style="font-weight:bold">
                                                <xsl:text>Settlement Account kind</xsl:text>
                                            </span>
                                        </th>
                                        <td>
                                            <span align="left" style="font-weight:bold">
                                                <xsl:choose>
                                                    <xsl:when test="@KIND='O'">
                                                        <xsl:text>Ordinary</xsl:text>
                                                    </xsl:when>
                                                    <xsl:when test="@KIND='I'">
                                                        <xsl:text>Concentration Risk Collateral</xsl:text>
                                                    </xsl:when>
                                                    <xsl:when test="@KIND='F'">
                                                        <xsl:text>Collective clearing collateral</xsl:text>
                                                    </xsl:when>
                                                    <xsl:when test="@KIND='G'">
                                                        <xsl:text>Stress Collateral</xsl:text>
                                                    </xsl:when>
                                                    <xsl:when test="@KIND='B'">
                                                        <xsl:text>&#171;GC Bonds&#187; pool</xsl:text>
                                                    </xsl:when>
                                                    <xsl:when test="@KIND='X'">
                                                        <xsl:text>&#171;GC Shares&#187; pool</xsl:text>
                                                    </xsl:when>
                                                    <xsl:when test="@KIND='E'">
                                                        <xsl:text>&#171;GC Expanded&#187; pool</xsl:text>
                                                    </xsl:when>
                                                    <xsl:when test="@KIND='U'">
                                                        <xsl:text>&#171;OFZ&#187; pool</xsl:text>
                                                    </xsl:when>
                                                    <xsl:when test="@KIND='M'">
                                                        <xsl:text>&#171;GC METAL&#187; pool</xsl:text>
                                                    </xsl:when>
                                                    <xsl:when test="@KIND='D'">
                                                        <xsl:text>Deposit</xsl:text>
                                                    </xsl:when>
                                                    <xsl:when test="@KIND='Z'">
                                                        <xsl:text>Settlement account for recording collateral for RF taxes</xsl:text>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:value-of select="@KIND"/>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </span>
                                        </td>
                                    </tr>

                                    <xsl:choose>
                                        <xsl:when test="@Z_CONNECTED">
                                            <tr bgcolor="#CCCCCC">
                                                <th align="left">
                                                    <span style="font-weight:bold">
                                                        <xsl:text>Connection with the Settlement account for recording collateral for RF taxes</xsl:text>
                                                    </span>
                                                </th>
                                                <td>
                                                    <span align="left" style="font-weight:bold">
                                                        <xsl:choose>
                                                            <xsl:when test="@Z_CONNECTED='Y'">
                                                                <xsl:text>Connected</xsl:text>
                                                            </xsl:when>
                                                            <xsl:when test="@Z_CONNECTED='N'">
                                                                <xsl:text>Not connected</xsl:text>
                                                            </xsl:when>
                                                        </xsl:choose>
                                                    </span>
                                                </td>
                                            </tr>
                                        </xsl:when>
                                    </xsl:choose>


                                    <xsl:choose>
                                        <xsl:when test="@FUND_NAME">
                                            <tr bgcolor="#CCCCCC">
                                                <th align="left">
                                                    <span style="font-weight:bold">
                                                        <xsl:text>Investment Fund Name</xsl:text>
                                                    </span>
                                                </th>
                                                <td>
                                                    <span align="left"
                                                          style="font-weight:bold; display:block; width:80ex; word-wrap:break-word;">
                                                        <xsl:value-of select="@FUND_NAME"/>
                                                    </span>
                                                </td>
                                            </tr>
                                        </xsl:when>
                                    </xsl:choose>

                                </thead>
                                <xsl:for-each select="CURRENCY">
                                    <xsl:sort order="descending" select="ACCOUNT_DETAILS/@SING_MAIN"/>
                                    <xsl:sort order="ascending" select="ACCOUNT_DETAILS/@CURRENCY"/>
                                    <tbody>
                                        <xsl:for-each select="ACCOUNT_DETAILS">
                                            <tr bgcolor="#CCCCCC">
                                                <th align="left" style="font-weight:normal">
                                                    <text>Account details</text>
                                                </th>
                                                <xsl:choose>
                                                    <xsl:when test="@SING_MAIN='Y'">
                                                        <th align="left" style="font-weight:normal">
                                                            <text>main</text>
                                                        </th>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <th align="left" style="font-weight:normal">
                                                            <text>additional</text>
                                                        </th>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </tr>
                                            <xsl:choose>
                                                <xsl:when test="../@ISO='RUB'">
                                                    <tr>
                                                        <th align="left">
                                                            <span style="font-weight:bold">
                                                                <xsl:text>BIC</xsl:text>
                                                            </span>
                                                        </th>
                                                        <th align="left">
                                                            <span style="font-weight:bold">
                                                                <xsl:text>Recipient BIC SWIFT</xsl:text>
                                                            </span>
                                                        </th>
                                                    </tr>
                                                    <tr>
                                                        <th>
                                                        </th>
                                                        <td align="left">
                                                            <xsl:for-each select="@F58A_BIC">
                                                                <span>
                                                                    <xsl:value-of select="string(.)"/>
                                                                </span>
                                                            </xsl:for-each>
                                                        </td>
                                                    </tr>
                                                    <tr>
                                                        <th align="left">
                                                            <span style="font-weight:bold">
                                                                <xsl:text>REG_BNAME1</xsl:text>
                                                            </span>
                                                        </th>
                                                        <th align="left">
                                                            <span style="font-weight:bold">
                                                                <xsl:text>Recipient bank name</xsl:text>
                                                            </span>
                                                        </th>
                                                    </tr>
                                                    <tr>
                                                        <th>
                                                        </th>
                                                        <td align="left">
                                                            <xsl:for-each select="@REG_BNAME1">
                                                                <span>
                                                                    <xsl:value-of select="string(.)"/>
                                                                </span>
                                                            </xsl:for-each>
                                                        </td>
                                                    </tr>

                                                    <tr>
                                                        <th align="left">
                                                            <span style="font-weight:bold">
                                                                <xsl:text>CORR_ACC</xsl:text>
                                                            </span>
                                                        </th>
                                                        <th align="left">
                                                            <span sstyle="font-weight:bold">
                                                                <xsl:text>Correspond account of bank of the recipient</xsl:text>
                                                            </span>
                                                        </th>
                                                    </tr>
                                                    <tr>
                                                        <th>
                                                        </th>
                                                        <td style="padding-bottom:5" align="left">
                                                            <xsl:text>&#160;</xsl:text>
                                                            <xsl:for-each select="@F58A_CORR_ACC">
                                                                <span align="left">
                                                                    <xsl:value-of select="string(.)"/>
                                                                </span>
                                                            </xsl:for-each>
                                                        </td>
                                                    </tr>
                                                    <tr>
                                                        <th align="left">
                                                            <span style="font-weight:bold">
                                                                <xsl:text>ACC_CREDIT</xsl:text>
                                                            </span>
                                                        </th>
                                                        <th align="left">
                                                            <span style="font-weight:bold">
                                                                <xsl:text>Recipient Account</xsl:text>
                                                            </span>
                                                        </th>
                                                    </tr>
                                                    <tr>
                                                        <th>
                                                        </th>
                                                        <td align="left">
                                                            <xsl:text>&#160;</xsl:text>
                                                            <xsl:for-each select="@F58A_ACC">
                                                                <span>
                                                                    <xsl:value-of select="string(.)"/>
                                                                </span>
                                                            </xsl:for-each>
                                                        </td>
                                                    </tr>
                                                    <tr>
                                                        <th align="left">
                                                            <span style="font-weight:bold">
                                                                <xsl:text>INN</xsl:text>
                                                            </span>
                                                        </th>
                                                        <th align="left">
                                                            <span style="font-weight:bold">
                                                                <xsl:text>Recipient's taxpayer identification number</xsl:text>
                                                            </span>
                                                        </th>
                                                    </tr>
                                                    <tr>
                                                        <th>
                                                        </th>
                                                        <td align="left">
                                                            <xsl:for-each select="@F58A_INN">
                                                                <span>
                                                                    <xsl:value-of select="string(.)"/>
                                                                </span>
                                                            </xsl:for-each>
                                                        </td>
                                                    </tr>
                                                    <tr>
                                                        <th align="left">
                                                            <span style="font-weight:bold">
                                                                <xsl:text>REG_NAME1</xsl:text>
                                                            </span>
                                                        </th>
                                                        <th align="left">
                                                            <span style="font-weight:bold">
                                                                <xsl:text>Recipient's name</xsl:text>
                                                            </span>
                                                        </th>
                                                    </tr>
                                                    <tr>
                                                        <th>
                                                        </th>
                                                        <td align="left">
                                                            <xsl:for-each select="@FIRMPURPOSE">
                                                                <span>
                                                                    <xsl:value-of select="string(.)"/>
                                                                </span>
                                                            </xsl:for-each>
                                                        </td>
                                                    </tr>
                                                </xsl:when>

                                                <xsl:otherwise>
                                                    <tr>
                                                        <th align="left">
                                                            <span style="font-weight:bold">
                                                                <xsl:text>CURRENCY</xsl:text>
                                                            </span>
                                                        </th>
                                                        <th align="left">
                                                            <span style="font-weight:bold">
                                                                <xsl:text>ISO currency code</xsl:text>
                                                            </span>
                                                        </th>
                                                    </tr>
                                                    <tr>
                                                        <th>
                                                        </th>
                                                        <td style="padding-bottom:5" align="left">
                                                            <xsl:for-each select="../@ISO">
                                                                <span align="left">
                                                                    <xsl:value-of select="string(.)"/>
                                                                </span>
                                                            </xsl:for-each>
                                                        </td>
                                                    </tr>

                                                    <xsl:if test="@F56A_BIC!=''">
                                                        <xsl:if test="@F56A_ACC!=''">
                                                            <tr>
                                                                <th align="left">

                                                                    <span style="font-weight:bold">
                                                                        <xsl:text>F56A_ACC</xsl:text>
                                                                    </span>
                                                                </th>
                                                                <th align="left">
                                                                    <span style="font-weight:bold">
                                                                        <xsl:text>Intermediary bank Account</xsl:text>
                                                                    </span>
                                                                </th>
                                                            </tr>
                                                            <tr>
                                                                <th>
                                                                </th>
                                                                <td align="left">
                                                                    <xsl:for-each select="@F56A_ACC">
                                                                        <span>
                                                                            <xsl:value-of select="string(.)"/>
                                                                        </span>
                                                                    </xsl:for-each>
                                                                </td>
                                                            </tr>
                                                        </xsl:if>
                                                        <tr>
                                                            <th align="left">
                                                                <span style="font-weight:bold">
                                                                    <xsl:text>F56A_BIC</xsl:text>
                                                                </span>
                                                            </th>
                                                            <th align="left">
                                                                <span style="font-weight:bold">
                                                                    <xsl:text>Intermediary bank BIC/ SWIFT</xsl:text>
                                                                </span>
                                                            </th>
                                                        </tr>
                                                        <tr>
                                                            <th>
                                                            </th>
                                                            <td style="padding-bottom:5" align="left">
                                                                <xsl:for-each select="@F56A_BIC">
                                                                    <span align="left">
                                                                        <xsl:value-of select="string(.)"/>
                                                                    </span>
                                                                </xsl:for-each>
                                                            </td>
                                                        </tr>
                                                    </xsl:if>

                                                    <xsl:if test="@F56A_ADRES!=''">
                                                        <xsl:if test="@F56A_ACC!=''">
                                                            <tr>
                                                                <th align="left">

                                                                    <span style="font-weight:bold">
                                                                        <xsl:text>F56D_ACC</xsl:text>
                                                                    </span>
                                                                </th>
                                                                <th align="left">
                                                                    <span style="font-weight:bold">
                                                                        <xsl:text>Intermediary bank Account</xsl:text>
                                                                    </span>
                                                                </th>
                                                            </tr>
                                                            <tr>
                                                                <th>
                                                                </th>
                                                                <td align="left">
                                                                    <xsl:for-each select="@F56A_ACC">
                                                                        <span>
                                                                            <xsl:value-of select="string(.)"/>
                                                                        </span>
                                                                    </xsl:for-each>
                                                                </td>
                                                            </tr>
                                                        </xsl:if>
                                                        <tr>
                                                            <th align="left">
                                                                <span style="font-weight:bold">
                                                                    <xsl:text>F56D_NAME</xsl:text>
                                                                </span>
                                                            </th>
                                                            <th align="left">
                                                                <span style="font-weight:bold">
                                                                    <xsl:text>Intermediary bank Name/ Address</xsl:text>
                                                                </span>
                                                            </th>
                                                        </tr>
                                                        <tr>
                                                            <th>
                                                            </th>
                                                            <td style="padding-bottom:5" align="left">
                                                                <xsl:for-each select="@F56A_ADRES">
                                                                    <span align="left">
                                                                        <xsl:value-of select="string(.)"/>
                                                                    </span>
                                                                </xsl:for-each>
                                                            </td>
                                                        </tr>
                                                    </xsl:if>

                                                    <xsl:if test="@F57A_BIC!=''">
                                                        <xsl:if test="@F57A_ACC!=''">
                                                            <tr>
                                                                <th align="left">

                                                                    <span style="font-weight:bold">
                                                                        <xsl:text>F57A_ACC</xsl:text>
                                                                    </span>
                                                                </th>
                                                                <th align="left">
                                                                    <span style="font-weight:bold">
                                                                        <xsl:text>Recipient bank Account</xsl:text>
                                                                    </span>
                                                                </th>
                                                            </tr>
                                                            <tr>
                                                                <th>
                                                                </th>
                                                                <td align="left">
                                                                    <xsl:for-each select="@F57A_ACC">
                                                                        <span>
                                                                            <xsl:value-of select="string(.)"/>
                                                                        </span>
                                                                    </xsl:for-each>
                                                                </td>
                                                            </tr>
                                                        </xsl:if>
                                                        <tr>
                                                            <th align="left">
                                                                <span style="font-weight:bold">
                                                                    <xsl:text>F57A_BIC</xsl:text>
                                                                </span>
                                                            </th>
                                                            <th align="left">
                                                                <span style="font-weight:bold">
                                                                    <xsl:text>Recipient bank BIC SWIFT</xsl:text>
                                                                </span>
                                                            </th>
                                                        </tr>
                                                        <tr>
                                                            <th>
                                                            </th>
                                                            <td style="padding-bottom:5" align="left">
                                                                <xsl:for-each select="@F57A_BIC">
                                                                    <span align="left">
                                                                        <xsl:value-of select="string(.)"/>
                                                                    </span>
                                                                </xsl:for-each>
                                                            </td>
                                                        </tr>
                                                    </xsl:if>

                                                    <xsl:if test="@F57A_ADRES!=''">
                                                        <xsl:if test="@F57A_ACC!=''">
                                                            <tr>
                                                                <th align="left">

                                                                    <span style="font-weight:bold">
                                                                        <xsl:text>F57D_ACC</xsl:text>
                                                                    </span>
                                                                </th>
                                                                <th align="left">
                                                                    <span style="font-weight:bold">
                                                                        <xsl:text>Recipient bank Account</xsl:text>
                                                                    </span>
                                                                </th>
                                                            </tr>
                                                            <tr>
                                                                <th>
                                                                </th>
                                                                <td align="left">
                                                                    <xsl:for-each select="@F57A_ACC">
                                                                        <span>
                                                                            <xsl:value-of select="string(.)"/>
                                                                        </span>
                                                                    </xsl:for-each>
                                                                </td>
                                                            </tr>
                                                        </xsl:if>
                                                        <tr>
                                                            <th align="left">
                                                                <span style="font-weight:bold">
                                                                    <xsl:text>F57D_NAME</xsl:text>
                                                                </span>
                                                            </th>
                                                            <th align="left">
                                                                <span style="font-weight:bold">
                                                                    <xsl:text>Recipient bank Name/ Address</xsl:text>
                                                                </span>
                                                            </th>
                                                        </tr>
                                                        <tr>
                                                            <th>
                                                            </th>
                                                            <td style="padding-bottom:5" align="left">
                                                                <xsl:for-each select="@F57A_ADRES">
                                                                    <span align="left">
                                                                        <xsl:value-of select="string(.)"/>
                                                                    </span>
                                                                </xsl:for-each>
                                                            </td>
                                                        </tr>
                                                    </xsl:if>

                                                    <xsl:if test="@F58A_BIC!=''">
                                                        <xsl:if test="@F58A_ACC!=''">
                                                            <tr>
                                                                <th align="left">
                                                                    <span style="font-weight:bold">
                                                                        <xsl:text>F58A_ACC</xsl:text>
                                                                    </span>
                                                                </th>
                                                                <th align="left">
                                                                    <span style="font-weight:bold">
                                                                        <xsl:text>Recipient Account</xsl:text>
                                                                    </span>
                                                                </th>
                                                            </tr>
                                                            <tr>
                                                                <th>
                                                                </th>
                                                                <td align="left">

                                                                    <xsl:for-each select="@F58A_ACC">
                                                                        <span>
                                                                            <xsl:value-of select="string(.)"/>
                                                                        </span>
                                                                    </xsl:for-each>
                                                                </td>
                                                            </tr>
                                                        </xsl:if>
                                                        <tr>
                                                            <th align="left">
                                                                <span style="font-weight:bold">
                                                                    <xsl:text>F58A_BIC </xsl:text>
                                                                </span>
                                                            </th>
                                                            <th align="left">
                                                                <span style="font-weight:bold">
                                                                    <xsl:text>Recipient BIC SWIFT</xsl:text>
                                                                </span>
                                                            </th>
                                                        </tr>
                                                        <tr>
                                                            <th>
                                                            </th>
                                                            <td align="left">
                                                                <xsl:for-each select="@F58A_BIC">
                                                                    <span>
                                                                        <xsl:value-of select="string(.)"/>
                                                                    </span>
                                                                </xsl:for-each>
                                                            </td>
                                                        </tr>
                                                    </xsl:if>
                                                    <xsl:if test="@F58A_ADRES!=''">
                                                        <xsl:if test="@F58A_ACC!=''">
                                                            <tr>
                                                                <th align="left">
                                                                    <span style="font-weight:bold">
                                                                        <xsl:text>F58D_ACC</xsl:text>
                                                                    </span>
                                                                </th>
                                                                <th align="left">
                                                                    <span style="font-weight:bold">
                                                                        <xsl:text>Recipient Account</xsl:text>
                                                                    </span>
                                                                </th>
                                                            </tr>
                                                            <tr>
                                                                <th>
                                                                </th>
                                                                <td align="left">

                                                                    <xsl:for-each select="@F58A_ACC">
                                                                        <span>
                                                                            <xsl:value-of select="string(.)"/>
                                                                        </span>
                                                                    </xsl:for-each>
                                                                </td>
                                                            </tr>
                                                        </xsl:if>
                                                        <tr>
                                                            <th align="left">
                                                                <span style="font-weight:bold">
                                                                    <xsl:text>F58D_NAME</xsl:text>
                                                                </span>
                                                            </th>
                                                            <th align="left">
                                                                <span style="font-weight:bold">
                                                                    <xsl:text>Recipient Name/ Address</xsl:text>
                                                                </span>
                                                            </th>
                                                        </tr>
                                                        <tr>
                                                            <th>
                                                            </th>
                                                            <td style="padding-bottom:5" align="left">
                                                                <xsl:for-each select="@F58A_ADRES">
                                                                    <span align="left">
                                                                        <xsl:value-of select="string(.)"/>
                                                                    </span>
                                                                </xsl:for-each>
                                                            </td>
                                                        </tr>
                                                    </xsl:if>
                                                    <tr>
                                                        <th>
                                                        </th>
                                                        <td align="left">
                                                            <xsl:for-each select="@FIRMPURPOSE">
                                                                <span>
                                                                    <xsl:value-of select="string(.)"/>
                                                                </span>
                                                            </xsl:for-each>
                                                        </td>
                                                    </tr>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                            <br/>
                                        </xsl:for-each>
                                    </tbody>
                                </xsl:for-each>
                            </table>
                        </xsl:for-each>

                    </div>
                </xsl:for-each>

            </body>
        </html>
    </xsl:template>
</xsl:stylesheet>
